@@ -503,9 +503,13 @@ ephy_gsb_storage_constructed (GObject *object)
   } else {
     LOG ("GSB database exists, opening...");
     success = ephy_gsb_storage_open_db (self);
-    if (success && !ephy_gsb_storage_check_schema_version (self)) {
-      LOG ("GSB database schema incompatibility, recreating database...");
-      ephy_gsb_storage_recreate_db (self);
+    if (success) {
+      if (!ephy_gsb_storage_check_schema_version (self)) {
+        LOG ("GSB database schema incompatibility, recreating database...");
+        ephy_gsb_storage_recreate_db (self);
+      } else {
+        self->is_operable = TRUE;
+      }
     }
   }
 }
@@ -527,8 +531,7 @@ ephy_gsb_storage_class_init (EphyGSBStorageClass *klass)
 
   obj_properties[PROP_DB_PATH] =
     g_param_spec_string ("db-path",
-                         "Database path",
-                         "The path of the SQLite file holding the lists of unsafe web resources",
+                         NULL, NULL,
                          NULL,
                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
